@@ -8,7 +8,7 @@ BEGIN {
     use Exporter ();
     use List::Util qw( min );
     our ($VERSION, @ISA, @EXPORT_OK);
-    $VERSION     = '0.06';
+    $VERSION     = '0.07';
     @ISA         = qw(Exporter);
     @EXPORT_OK   = qw(
         social_security_benefits
@@ -54,17 +54,17 @@ B<Acronyms:>
 =item *
 
 B<SSBW:> I<Social Security Benefits Worksheet>, I<e.g.,> as found on page 32
-of IRS Form 1040 Instructions for filing year 2023.
+of IRS Form 1040 Instructions for filing year 2024.
 
 =item *
 
 B<QDCGTW:> I<Qualified Dividends and Capital Gain Tax Worksheet>, I<e.g.,> as
-found on page 37 of those 2023 Instructions.
+found on page 36 of those 2024 Instructions.
 
 =back
 
 The current version of this library supports the SSBW and most of the QDCGTW
-for filing years 2022 and 2023.  Future versions may extend the support of
+for filing years 2022, 2023 and 2024.  Future versions may extend the support of
 those worksheets forwards and backwords; may offer more complete support for
 the QDCGTW; and may offer support for other worksheets found within the Form
 1040 instructions.
@@ -83,7 +83,7 @@ attorney.  Use at your own risk!>
 
 Calculate taxable social security benefits per the SSBW for the purpose of
 entering the amount of such taxable benefits on IRS Form 1040.  (For filing
-year 2023, these would be lines 6a and 6b on that form.)
+year 2024, these would be lines 6a and 6b on that form.)
 
     my $benefits = social_security_benefits( $inputs );
 
@@ -156,11 +156,15 @@ my %data_2022_ssb = (
 # inspection of 2023 Soc Sec worksheet indicates no change in
 # parameters
 my %data_2023_ssb = map { $_ => $data_2022_ssb{$_} } keys %data_2022_ssb;
+# inspection of 2024 Soc Sec worksheet indicates no change in
+# parameters
+my %data_2024_ssb = map { $_ => $data_2023_ssb{$_} } keys %data_2023_ssb;
 
 our %params = (
     ssb => {
         2022 => { %data_2022_ssb },
         2023 => { %data_2023_ssb },
+        2024 => { %data_2024_ssb },
     },
     qd => {
         2022 => {
@@ -187,6 +191,18 @@ our %params = (
             percentage_a                => 0.15,
             percentage_b                => 0.20,
         },
+        2024 => {
+            worksheet_line_count        => 21,
+            single_or_married_sep_amt_a => 47025,
+            married_amt_a               => 94050,
+            head_of_household_amt_a     => 63000,
+            single_amt_b                => 518900,
+            married_sep_amt_b           => 291850,
+            married_amt_b               => 583750,
+            head_of_household_amt_b     => 551350,
+            percentage_a                => 0.15,
+            percentage_b                => 0.20,
+        },
     },
 );
 
@@ -203,8 +219,7 @@ sub social_security_benefits {
 =item * Purpose
 
 Calculate data needed for the purpose of completing all entries (except
-checkboxes) on the Social Security Benefits Worksheet (For filing year 2023,
-these would be lines 6a and 6b on that form.)
+checkboxes) on the Social Security Benefits Worksheet.
 
     my $worksheet_data = social_security_worksheet_data( $inputs );
 
@@ -436,7 +451,7 @@ sub pp_ssbw {
 
 B<Partial calculation> of taxes due per the QDCGTW for the purpose of
 entering the amount of such taxes due on IRS Form 1040.  (For filing
-year 2023, these would be Form 1040 line 16.)
+year 2024, these would be Form 1040 line 16.)
 
     my $lines = qualified_dividends_capital_gains_tax( $inputs );
 
